import {
  select,
  csv,
  scaleLinear,
  max,
  scalePoint,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg=select('svg');



const width=+svg.attr('width');
const height= +svg.attr('height');

const render= data => {
  const margin={top:20,right:20,bottom:20,left:100}
  const innerWidth=width-margin.left-margin.right
  const innerHeight=height-margin.top-margin.bottom
  
  const xScale=scaleLinear()
  							.domain([0,max(data,d=>d.population)])
  							.range([0,innerWidth])
  							.nice();
  
  
  const yScale=scalePoint()
  							.domain(data.map(d=>d.country))
  							.range([0,innerHeight])
  							.padding(0.7)
  
  
  console.log(xScale.range())
  const g=svg.append('g')
  					.attr('transform',`translate(${margin.left},${margin.top})`)
  
  
  const xAxisTickFormat= number => format('.3s')(number)
  				.replace('G','B')
  const xAxis=axisBottom(xScale)
  							.tickFormat(xAxisTickFormat)
  							.tickSize(-innerHeight)
  
  
  const yAxis=axisLeft(yScale)
  							.tickSize(-innerWidth)
  
  g.append('g')
    	.call(yAxis)
  		.selectAll('.domain')
  		.remove()
  
  
  
  
  const xAxisG=g.append('g').call(xAxis)
  		.attr('transform', `translate(0,${innerHeight})`)
  
  g.append('text')
  				.attr('y',0)
  				.attr('fill','black')
  				.text('Population')
  
	g.selectAll('circle').data(data)
  				.enter().append('circle')
  				.attr('cy', d=> yScale(d.country))
  				.attr('cx', d => xScale(d.population))
          .attr('r', 18)
  
  g.append('text')
  		.attr('y',-10)
  		.text('Top 10 most populous countries')
}

csv('https://vizhub.com/curran/datasets/auto-mpg.csv').then(data => {
				console.log(data)
  			
        	/*
          acceleration: "12"
          cylinders: "8"
          displacement: "307"
          horsepower: "130"
          mpg: "18"
          name: "chevrolet chevelle malibu"
          origin: "USA"
          population: NaN
          weight: "3504"
          year: "1970"
        */
  			data.forEach(d => {
        	d.mpg=+d.mpg
          d.cylinders=+d.cylinders
          d.acceleration=+d.acceleration
          d.displacement=+d.displacement
          d.horsepower=+d.horsepower
          d.weight=+d.weight
          d.year=+d.year
        })
  			
  			render(data)
	})
